@@ -19,7 +19,7 @@ RunModel_GR2M <- function(InputsModel, RunOptions, Param) {
     RunOptions$IndPeriod_WarmUp <- NULL
   }
   IndPeriod1   <- c(RunOptions$IndPeriod_WarmUp, RunOptions$IndPeriod_Run)
-  LInputSeries <- as.integer(length(IndPeriod1))
+  LInputSeries <- length(IndPeriod1)
   if ("all" %in% RunOptions$Outputs_Sim) {
     IndOutputs <- as.integer(1:length(RunOptions$FortranOutputs$GR))
   } else {
@@ -43,18 +43,16 @@ RunModel_GR2M <- function(InputsModel, RunOptions, Param) {
                       LInputs = LInputSeries,                             ### length of input and output series
                       InputsPrecip = InputsModel$Precip[IndPeriod1],      ### input series of total precipitation [mm/month]
                       InputsPE = InputsModel$PotEvap[IndPeriod1],         ### input series potential evapotranspiration [mm/month]
-                      NParam = as.integer(length(Param)),                 ### number of model parameter
+                      NParam = length(Param),                             ### number of model parameter
                       Param = Param,                                      ### parameter set
-                      NStates = as.integer(length(RunOptions$IniStates)), ### number of state variables used for model initialising
+                      NStates = length(RunOptions$IniStates),             ### number of state variables used for model initialising
                       StateStart = RunOptions$IniStates,                  ### state variables used when the model run starts
-                      NOutputs = as.integer(length(IndOutputs)),          ### number of output series
+                      NOutputs = length(IndOutputs),                      ### number of output series
                       IndOutputs = IndOutputs,                            ### indices of output series
                       ## outputs
-                      Outputs = matrix(as.double(-99e9), nrow = LInputSeries, ncol = length(IndOutputs)), ### output series [mm or mm/month]
-                      StateEnd = rep(as.double(-99e9), length(RunOptions$IniStates))                      ### state variables at the end of the model run
+                      Outputs = matrix(-99e9, nrow = LInputSeries, ncol = length(IndOutputs)), ### output series [mm or mm/month]
+                      StateEnd = rep(-99e9, length(RunOptions$IniStates))                      ### state variables at the end of the model run
   )
-  RESULTS$Outputs[RESULTS$Outputs   <= -99e8] <- NA
-  RESULTS$StateEnd[RESULTS$StateEnd <= -99e8] <- NA
   if (ExportStateEnd) {
     RESULTS$StateEnd <- CreateIniStates(FUN_MOD = RunModel_GR2M, InputsModel = InputsModel,
                                         ProdStore = RESULTS$StateEnd[1L], RoutStore = RESULTS$StateEnd[2L], ExpStore = NULL,
