@@ -6,7 +6,7 @@ RunModel_Lag <- function(InputsModel, RunOptions, Param, QcontribDown) {
     stop("'InputsModel' must be of class 'InputsModel'")
   }
   if (!inherits(InputsModel, "SD")) {
-    stop("'InputsModel' must be of class 'SD'")
+    warning("'InputsModel' may better be of class 'SD'")
   }
   if (!inherits(RunOptions, "RunOptions")) {
     stop("'RunOptions' must be of class 'RunOptions'")
@@ -15,26 +15,49 @@ RunModel_Lag <- function(InputsModel, RunOptions, Param, QcontribDown) {
     stop("'Param' must be a numeric vector")
   }
   if (sum(!is.na(Param)) != NParam) {
-    stop(paste("'Param' must be a vector of length", NParam, "and contain no NA"))
+    stop(paste(
+      "'Param' must be a vector of length",
+      NParam,
+      "and contain no NA"
+    ))
   }
   if (inherits(QcontribDown, "OutputsModel")) {
     if (is.null(QcontribDown$Qsim)) {
-      stop("'QcontribDown' should contain a key 'Qsim' containing the output of the runoff of the downstream subcatchment")
+      stop(
+        "'QcontribDown' should contain a key 'Qsim' containing the output of the runoff of the downstream subcatchment"
+      )
     }
     if (length(QcontribDown$Qsim) != length(RunOptions$IndPeriod_Run)) {
-      stop("Time series Qsim in 'QcontribDown' should have the same length as 'RunOptions$IndPeriod_Run'")
+      stop(
+        "Time series Qsim in 'QcontribDown' should have the same length as 'RunOptions$IndPeriod_Run'"
+      )
     }
-    if (!identical(RunOptions$IndPeriod_WarmUp, 0L) && !identical(RunOptions$Outputs_Sim, RunOptions$Outputs_Cal)) {
+    if (
+      !identical(RunOptions$IndPeriod_WarmUp, 0L) &&
+        !identical(RunOptions$Outputs_Sim, RunOptions$Outputs_Cal)
+    ) {
       # This test is not necessary during calibration but usefull in other cases because
       # WarmUpQsim is then used for downstream sub-basins because of the delay in Qupstream
-      if (is.null(QcontribDown$RunOptions$WarmUpQsim) ||
-          length(QcontribDown$RunOptions$WarmUpQsim) != length(RunOptions$IndPeriod_WarmUp)) {
-        stop("Time series WarmUpQsim in 'QcontribDown' should have the same length as 'RunOptions$IndPeriod_WarmUp'")
+      if (
+        is.null(QcontribDown$RunOptions$WarmUpQsim) ||
+          length(QcontribDown$RunOptions$WarmUpQsim) !=
+            length(RunOptions$IndPeriod_WarmUp)
+      ) {
+        stop(
+          "Time series WarmUpQsim in 'QcontribDown' should have the same length as 'RunOptions$IndPeriod_WarmUp'"
+        )
       }
     }
+    if (isTRUE(RunOptions$HasRoutedFlowLeaks) && is.null(QcontribDown$Exch)) {
+      stop(
+        "'QcontribDown' should contain a key 'Exch' containing the output of the water exchange function"
+      )
+    }
   } else if (is.vector(QcontribDown) && is.numeric(QcontribDown)) {
     if (length(QcontribDown) != length(RunOptions$IndPeriod_Run)) {
-      stop("'QcontribDown' should have the same length as 'RunOptions$IndPeriod_Run'")
+      stop(
+        "'QcontribDown' should have the same length as 'RunOptions$IndPeriod_Run'"
+      )
     }
   } else {
     stop("'QcontribDown' must be a numeric vector or a 'OutputsModel' object")
@@ -45,25 +68,40 @@ RunModel_Lag <- function(InputsModel, RunOptions, Param, QcontribDown) {
   if (identical(RunOptions$IndPeriod_WarmUp, 0L)) {
     RunOptions$IndPeriod_WarmUp <- NULL
   }
-  IndPeriod1   <- c(RunOptions$IndPeriod_WarmUp, RunOptions$IndPeriod_Run)
+  IndPeriod1 <- c(RunOptions$IndPeriod_WarmUp, RunOptions$IndPeriod_Run)
   LInputSeries <- as.integer(length(IndPeriod1))
-  IndPeriod2 <- (length(RunOptions$IndPeriod_WarmUp)+1):LInputSeries
+  IndPeriod2 <- (length(RunOptions$IndPeriod_WarmUp) + 1):LInputSeries
+  HasRoutedFlowLeaks <- FALSE
 
   if (inherits(QcontribDown, "OutputsModel")) {
     OutputsModel <- QcontribDown
     if (is.null(OutputsModel$RunOptions$WarmUpQsim)) {
-      OutputsModel$RunOptions$WarmUpQsim <- rep(NA, length(RunOptions$IndPeriod_WarmUp))
+      OutputsModel$RunOptions$WarmUpQsim <- rep(
+        NA,
+        length(RunOptions$IndPeriod_WarmUp)
+      )
     }
     QsimDown <- c(OutputsModel$RunOptions$WarmUpQsim, OutputsModel$Qsim)
+    if (isTRUE(RunOptions$HasRoutedFlowLeaks)) {
+      HasRoutedFlowLeaks <- TRUE
+      Exch <- sapply(OutputsModel$Exch, min, 0)
+      OutputsModel$UpstreamLeaks <- matrix(
+        0,
+        ncol = length(InputsModel$LengthHydro),
+        nrow = length(IndPeriod2)
+      )
+    }
   } else if (is.vector(QcontribDown) && is.numeric(QcontribDown)) {
     OutputsModel <- list()
     class(OutputsModel) <- c("OutputsModel", class(RunOptions)[-1])
-    QsimDown <- c(rep(NA, length(RunOptions$IndPeriod_WarmUp)),
-                  QcontribDown)
+    QsimDown <- c(rep(NA, length(RunOptions$IndPeriod_WarmUp)), QcontribDown)
   }
 
   ## propagation time from upstream meshes to outlet
-  PT <- InputsModel$LengthHydro * 1e3 / Param[1L] / RunOptions$FeatFUN_MOD$TimeStep
+  PT <- InputsModel$LengthHydro *
+    1e3 /
+    Param[1L] /
+    RunOptions$FeatFUN_MOD$TimeStep
   HUTRANS <- rbind(1 - (PT - floor(PT)), PT - floor(PT))
 
   ## set up initial states
@@ -91,7 +129,7 @@ RunModel_Lag <- function(InputsModel, RunOptions, Param, QcontribDown) {
       function(iUpBasins) {
         iWarmUp <- seq.int(
           from = max(1, IndPeriod1[1] - floor(PT[iUpBasins]) - 1),
-          to   = max(1, IndPeriod1[1] - 1)
+          to = max(1, IndPeriod1[1] - 1)
         )
         ini <- InputsModel$Qupstream[iWarmUp, iUpBasins]
         if (length(ini) != floor(PT[iUpBasins] + 1)) {
@@ -106,11 +144,41 @@ RunModel_Lag <- function(InputsModel, RunOptions, Param, QcontribDown) {
 
   ## Lag model computation
   Qsim_m3 <- QsimDown *
-    InputsModel$BasinAreas[length(InputsModel$BasinAreas)] * 1e3
+    InputsModel$BasinAreas[length(InputsModel$BasinAreas)] *
+    1e3
 
   for (upstream_basin in seq_len(NbUpBasins)) {
-    Qupstream <- c(IniStates[[upstream_basin]],
-                   InputsModel$Qupstream[IndPeriod1, upstream_basin])
+    Qupstream <- c(
+      IniStates[[upstream_basin]],
+      InputsModel$Qupstream[IndPeriod1, upstream_basin]
+    )
+    # Leaks application on routed flows
+    if (HasRoutedFlowLeaks) {
+      # Leak are applied based on downstream sub-basin area and residence time
+      Eup <- Exch *
+        PT[upstream_basin] *
+        InputsModel$BasinAreas[length(InputsModel$BasinAreas)] *
+        1e3
+      # Leaks are shared between upstream flows based on their routing length
+      if (sum(InputsModel$LengthHydro) > 0) {
+        Eup <- Eup *
+          InputsModel$LengthHydro[upstream_basin] /
+          sum(InputsModel$LengthHydro)
+      }
+      I2 <- IndPeriod2 + 1
+      # Cap leaks to upstream flow
+      iOverLeaks <- which(Qupstream[I2] + Eup < 0)
+      if (length(iOverLeaks) > 0) {
+        Eup[iOverLeaks] <- -Qupstream[iOverLeaks]
+      }
+      # Don't apply leaks on upstream negative flows (distant abstractions)
+      Eup[Qupstream[I2] < 0] <- 0
+      # Store Eup separately for each upstream flow
+      OutputsModel$UpstreamLeaks[, upstream_basin] <- Eup
+      # Apply leaks on upstream flow
+      Qupstream[I2] <- Qupstream[I2] + Eup
+    }
+
     # message("Qupstream[", upstream_basin, "]: ", paste(Qupstream, collapse = ", "))
     Qsim_m3 <- Qsim_m3 +
       Qupstream[2:(1 + LInputSeries)] * HUTRANS[1, upstream_basin] +
@@ -125,7 +193,9 @@ RunModel_Lag <- function(InputsModel, RunOptions, Param, QcontribDown) {
 
   if ("Qsim" %in% RunOptions$Outputs_Sim) {
     # Convert back Qsim to mm
-    OutputsModel$Qsim <- Qsim_m3[IndPeriod2] / sum(InputsModel$BasinAreas, na.rm = TRUE) / 1e3
+    OutputsModel$Qsim <- Qsim_m3[IndPeriod2] /
+      sum(InputsModel$BasinAreas, na.rm = TRUE) /
+      1e3
     # message("Qsim: ", paste(OutputsModel$Qsim, collapse = ", "))
   }
 
@@ -137,29 +207,49 @@ RunModel_Lag <- function(InputsModel, RunOptions, Param, QcontribDown) {
   # Warning for negative flows or NAs only in extended outputs
   if (length(RunOptions$Outputs_Sim) > 2) {
     if (any(OutputsModel$Qsim[!is.na(OutputsModel$Qsim)] < 0)) {
-      warning(length(which(OutputsModel$Qsim < 0)), " time steps with negative flow, set to zero.")
-      OutputsModel$Qsim[OutputsModel$Qsim < 0] <- 0
+      warning(
+        length(which(OutputsModel$Qsim < 0)),
+        " time steps with negative flow, set to zero."
+      )
     }
     # Warning for NAs
     if (any(is.na(OutputsModel$Qsim))) {
-      warning(length(which(is.na(OutputsModel$Qsim))), " time steps with NA values")
+      warning(
+        length(which(is.na(OutputsModel$Qsim))),
+        " time steps with NA values"
+      )
     }
   }
+  OutputsModel$Qsim[OutputsModel$Qsim < 0] <- 0
 
   if ("StateEnd" %in% RunOptions$Outputs_Sim) {
-    SD <- lapply(seq(NbUpBasins), function(x) {
-      lastTS <- RunOptions$IndPeriod_Run[length(RunOptions$IndPeriod_Run)]
-      InputsModel$Qupstream[(lastTS - floor(PT[x])):lastTS, x]
-    })
-    if (is.null(OutputsModel$StateEnd)) {
-      OutputsModel$StateEnd <- CreateIniStates(RunModel_Lag, InputsModel, SD = SD)
-    } else {
-      OutputsModel$StateEnd$SD <- SD
+    if (NbUpBasins > 0) {
+      SD <- lapply(seq(NbUpBasins), function(x) {
+        lastTS <- RunOptions$IndPeriod_Run[length(RunOptions$IndPeriod_Run)]
+        firstTS <- lastTS - floor(PT[x])
+        if (firstTS < 1) {
+          c(
+            rep(InputsModel$Qupstream[1, x], 1 - firstTS),
+            InputsModel$Qupstream[1:lastTS, x]
+          )
+        } else {
+          InputsModel$Qupstream[firstTS:lastTS, x]
+        }
+      })
+      if (is.null(OutputsModel$StateEnd)) {
+        OutputsModel$StateEnd <- list(SD = SD)
+      } else {
+        OutputsModel$StateEnd$SD <- SD
+      }
     }
     # message("StateEnd: ", paste(OutputsModel$StateEnd$SD, collapse = ", "))
   }
   if ("WarmUpQsim" %in% RunOptions$Outputs_Sim) {
-    OutputsModel$RunOptions$WarmUpQsim <- Qsim_m3[seq_len(length(RunOptions$IndPeriod_WarmUp))] / sum(InputsModel$BasinAreas, na.rm = TRUE) / 1e3
+    OutputsModel$RunOptions$WarmUpQsim <- Qsim_m3[seq_len(length(
+      RunOptions$IndPeriod_WarmUp
+    ))] /
+      sum(InputsModel$BasinAreas, na.rm = TRUE) /
+      1e3
   }
 
   if ("Param" %in% RunOptions$Outputs_Sim) {
