@@ -2,6 +2,6 @@ SeriesAggreg.OutputsModel <- function(x, Format, ...) {
   SeriesAggreg.list(x,
                     Format,
                     ConvertFun = NA,
-                    except = "StateEnd",
+                    except = c("RunOptions", "StateEnd"),
                     ...)
 }
